==> hpijs-1.1.tar.gz: hpijs-1.1/dj895_maps.cpp <==
/*****************************************************************************\
  dj895_maps.cpp : Color maps for DJ895

  Copyright (c) 1996 - 2001, Hewlett-Packard Co.
  All rights reserved.

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:
  1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
  2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
  3. Neither the name of Hewlett-Packard nor the names of its
     contributors may be used to endorse or promote products derived
     from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR IMPLIED
  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN
  NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
  TO, PATENT INFRINGEMENT; PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
\*****************************************************************************/


#include "config.h"

APDK_BEGIN_NAMESPACE

unsigned long ulMapVENICE_KCMY[ 9*9*9 ]=
{
1819176703UL, 79494215UL, 112983330UL, 79035667UL, 78183948UL, 60489224UL, 59571718UL, 42007811UL, 7405312UL,
4230922555UL, 655358293UL, 176553263UL, 128253208UL, 61209869UL, 60751368UL, 26606852UL, 9305345UL, 8650496UL,
4248940299UL, 3776766759UL, 756415798UL, 308083743UL, 142671120UL, 59440646UL, 9239553UL, 9109248UL, 8779520UL,
4248086274UL, 4214276619UL, 2786390812UL, 942206231UL, 491516427UL, 224131588UL, 6616320UL, 7399168UL, 7857664UL,
4264010752UL, 4247302401UL, 4011647240UL, 2148919051UL, 993059843UL, 507241472UL, 138274048UL, 4837888UL, 5950720UL,
4262961664UL, 4246251520UL, 4229221122UL, 3239632384UL, 1763828224UL, 723902208UL, 304536064UL, 2674688UL, 3916800UL,
4278952960UL, 4245530112UL, 4245339136UL, 3641362432UL, 2265566208UL, 1108008960UL, 437574912UL, 119069440UL, 2280192UL,
4278233600UL, 4211122944UL, 4278235392UL, 3825252352UL, 2785196032UL, 1677774080UL, 738253824UL, 302835968UL, 1039616UL,
4278236928UL, 4278234112UL, 4278234368UL, 3942690560UL, 3204492544UL, 2281749504UL, 1359008000UL, 620816128UL, 65280UL,
3422292824UL, 536567352UL, 217763358UL, 133298706UL, 47578636UL, 46333448UL, 11795717UL, 11009281UL, 9365504UL,
4252790811UL, 1819700817UL, 230487086UL, 112721175UL, 61734412UL, 60882438UL, 9829634UL, 9043712UL, 7992832UL,
4233393664UL, 4064522015UL, 1346225965UL, 528017689UL, 126482957UL, 25951492UL, 8978176UL, 8648448UL, 7924992UL,
4248074240UL, 4231703558UL, 3409695758UL, 1430441485UL, 811653892UL, 308602880UL, 6545664UL, 7133696UL, 7395840UL,
4263805952UL, 4264010752UL, 4028613125UL, 2553530624UL, 1245367297UL, 524010752UL, 54051840UL, 4767488UL, 5883136UL,
4279601152UL, 4245789184UL, 4161583616UL, 2886710016UL, 1544795648UL, 689813504UL, 253801216UL, 2600448UL, 3780608UL,
4245129216UL, 4211118848UL, 3942687488UL, 3036717056UL, 2013308416UL, 1023652608UL, 369865216UL, 68201984UL, 2205952UL,
4278225408UL, 3791685632UL, 3456142080UL, 3003157760UL, 2365624576UL, 1509989376UL, 755018496UL, 167817216UL, 897024UL,
4278227456UL, 3456141056UL, 3288369152UL, 3019933952UL, 2617281536UL, 1979749120UL, 1224778496UL, 587248896UL, 48640UL,
4143384622UL, 1744640554UL, 519916828UL, 184397586UL, 50262795UL, 64486664UL, 14285826UL, 12842496UL, 10868224UL,
4255729162UL, 3084330804UL, 569604134UL, 251059983UL, 98368262UL, 13040899UL, 11861760UL, 10745856UL, 9232896UL,
4250816512UL, 4135742478UL, 2223998487UL, 1253754887UL, 228518406UL, 9499904UL, 8974336UL, 8383744UL, 7593472UL,
4248392704UL, 4249515008UL, 3461321226UL, 2172105475UL, 879538176UL, 191088128UL, 6606080UL, 7000064UL, 6868992UL,
4280572928UL, 4264064512UL, 3928660994UL, 2402325760UL, 1195023616UL, 490381056UL, 54176256UL, 4829184UL, 5683456UL,
4279723264UL, 4262689024UL, 3926823168UL, 2702347776UL, 1629131520UL, 723292928UL, 253662208UL, 2594816UL, 3842560UL,
4278676224UL, 4278220032UL, 3674242816UL, 2785051136UL, 1845527040UL, 990088448UL, 403214336UL, 34442752UL, 2069504UL,
4278219264UL, 3741346560UL, 3120591104UL, 2701161984UL, 2147514624UL, 1426095872UL, 755010048UL, 184585728UL, 692224UL,
4278220544UL, 3439356672UL, 2952818944UL, 2667607552UL, 2298509056UL, 1795193088UL, 1157661440UL, 587239936UL, 37632UL,
4259653128UL, 2868776476UL, 1174216726UL, 519914253UL, 134125065UL, 16439296UL, 15459328UL, 13752320UL, 11977728UL,
4273417220UL, 3891139612UL, 1375215645UL, 418995213UL, 49524481UL, 14866176UL, 13754624UL, 12442880UL, 10931968UL,
4269093120UL, 4221780741UL, 3066452487UL, 1153592327UL, 280338688UL, 10863360UL, 10408704UL, 9688832UL, 8900864UL,
4265753600UL, 4250487808UL, 3530710787UL, 1954444800UL, 813005824UL, 174693632UL, 6993152UL, 7062272UL, 6931456UL,
4280828416UL, 4247604224UL, 3946407424UL, 2470209280UL, 1262513408UL, 507607040UL, 54495744UL, 4955392UL, 5549056UL,
4263135488UL, 4263006720UL, 4028065024UL, 2686019584UL, 1629382400UL, 773942784UL, 253850368UL, 2851072UL, 3969280UL,
4245245184UL, 4211101952UL, 3842006784UL, 2701156864UL, 1829069568UL, 1023961088UL, 403467008UL, 814336UL, 2195200UL,
4278211840UL, 3892335360UL, 3238024960UL, 2617270528UL, 2046846208UL, 1392534784UL, 721447424UL, 184577536UL, 684544UL,
4160773120UL, 3506459648UL, 3003144704UL, 2566939392UL, 2181064448UL, 1694524928UL, 1124100608UL, 570455040UL, 29696UL,
4276100357UL, 3573419536UL, 1895633680UL, 939336200UL, 452802307UL, 16152576UL, 15248896UL, 14072320UL, 12693248UL,
4257226242UL, 4159906309UL, 2281312784UL, 905585670UL, 217727746UL, 15105792UL, 14331392UL, 13745920UL, 12433664UL,
4287243264UL, 4256376834UL, 3403102720UL, 1557018882UL, 449465600UL, 12156160UL, 12298752UL, 11779072UL, 10665472UL,
4283377152UL, 4268043520UL, 3582212864UL, 1988114432UL, 797067776UL, 142174720UL, 8163072UL, 8431872UL, 8107264UL,
4264307712UL, 4265030400UL, 3745725441UL, 2420391680UL, 1196049920UL, 491344896UL, 38169088UL, 5277952UL, 5676800UL,
4263261184UL, 4263393280UL, 3827318784UL, 2703311360UL, 1646610176UL, 807947008UL, 220681216UL, 3237376UL, 4160768UL,
4245371392UL, 4245110016UL, 3876012288UL, 2835956992UL, 1879722240UL, 1057835776UL, 420433920UL, 34690304UL, 2385920UL,
4278206208UL, 3959438848UL, 3372236800UL, 2701149696UL, 2046840064UL, 1375751936UL, 721441024UL, 184570880UL, 744448UL,
4076880896UL, 3456122880UL, 3019916032UL, 2634042112UL, 2181059840UL, 1660966656UL, 1157650176UL, 587225856UL, 23808UL,
4275835907UL, 4043119616UL, 2784892929UL, 1358829315UL, 603855360UL, 150741248UL, 15621120UL, 14257152UL, 12949760UL,
4274394113UL, 4227209216UL, 3069974272UL, 1375344384UL, 335157248UL, 15411712UL, 14508800UL, 14062848UL, 13083392UL,
4271446016UL, 4223538689UL, 3234600704UL, 1690966528UL, 550379520UL, 12791808UL, 12872192UL, 12949248UL, 12297984UL,
4284291584UL, 4268891136UL, 3448184064UL, 2038897664UL, 898441472UL, 160182784UL, 9593344UL, 10258944UL, 9870848UL,
4265024512UL, 4265484288UL, 3628671744UL, 2370708224UL, 1330915328UL, 458502656UL, 5458688UL, 6451456UL, 6785536UL,
4280427008UL, 4263715584UL, 3727172864UL, 2552701952UL, 1580018176UL, 758065920UL, 237976064UL, 3625472UL, 4484608UL,
4245628160UL, 4245563136UL, 3708758272UL, 2735614720UL, 1863331328UL, 1041445376UL, 437531904UL, 35077376UL, 2708224UL,
4278201344UL, 3992988672UL, 3355454464UL, 2717920768UL, 2063610624UL, 1308636928UL, 687879936UL, 167786752UL, 869888UL,
3774886912UL, 3288346624UL, 2919247872UL, 2566927616UL, 2181053440UL, 1660961536UL, 1140868096UL, 603997696UL, 18176UL,
4258860033UL, 4160293632UL, 3170699520UL, 1660750336UL, 738069504UL, 201198336UL, 16192256UL, 14632192UL, 13398784UL,
4257745665UL, 4226745857UL, 3220308480UL, 1609499648UL, 519046912UL, 15404032UL, 14622976UL, 14045184UL, 13400832UL,
4255321344UL, 4173399296UL, 3082880256UL, 1841497856UL, 734464512UL, 63245568UL, 12986368UL, 13195264UL, 12812800UL,
4251717120UL, 4219341568UL, 3213428736UL, 2055866880UL, 1016073472UL, 261492480UL, 10496256UL, 11098624UL, 11239936UL,
4248834304UL, 4249227520UL, 3477868032UL, 2337542144UL, 1331368192UL, 526325248UL, 6497280UL, 7885312UL, 8549376UL,
4280685824UL, 4247196672UL, 3542750208UL, 2536379136UL, 1614091776UL, 808916992UL, 205005312UL, 4472320UL, 5463552UL,
4279637504UL, 4229240832UL, 3490911488UL, 2635339520UL, 1779897856UL, 974723328UL, 505355520UL, 1910528UL, 3097600UL,
4194310144UL, 4060092672UL, 3405781504UL, 2684361472UL, 1962941440UL, 1241652992UL, 654582016UL, 184951552UL, 1192960UL,
3590333184UL, 3154125056UL, 2818580992UL, 2466259712UL, 2080384512UL, 1593846528UL, 1073753856UL, 570437632UL, 12800UL,
4208197632UL, 4227006464UL, 3506110464UL, 2113470464UL, 955777024UL, 402457344UL, 33358080UL, 15994112UL, 14235904UL,
4291166208UL, 3956736000UL, 3151429632UL, 2044329984UL, 903675904UL, 249626624UL, 14485504UL, 14096128UL, 13712896UL,
4289003520UL, 3836936192UL, 2947678208UL, 2109079552UL, 1035796480UL, 281018368UL, 12716544UL, 13114880UL, 13190656UL,
4201906176UL, 3900702720UL, 2978611200UL, 2139881472UL, 1217462272UL, 412418048UL, 10356992UL, 11543296UL, 12013056UL,
4249355008UL, 4081647616UL, 3209887744UL, 2254045184UL, 1365114880UL, 610533888UL, 74187776UL, 8725504UL, 9588224UL,
4247389696UL, 4180346112UL, 3425633280UL, 2486436864UL, 1631192064UL, 842925568UL, 222365696UL, 5447936UL, 6702592UL,
4279634432UL, 4145482496UL, 3373664256UL, 2585331456UL, 1797064704UL, 1025509632UL, 472124416UL, 2561536UL, 3945984UL,
4278651648UL, 4077259776UL, 3355707904UL, 2667908096UL, 1963395840UL, 1225263872UL, 638193152UL, 370546176UL, 1713152UL,
3858764288UL, 3321893376UL, 2868908800UL, 2432701184UL, 2013271552UL, 1526732288UL, 1006639104UL, 520100096UL, 7168UL,
4293197824UL, 4293918720UL, 3673292800UL, 2616262656UL, 1492058112UL, 770834432UL, 334888960UL, 100335616UL, 16711680UL,
4223860736UL, 3602972672UL, 3066298368UL, 2395668480UL, 1422917632UL, 684982272UL, 249036800UL, 14352384UL, 14417920UL,
4020436992UL, 3517448192UL, 2896822272UL, 2309947392UL, 1488191488UL, 716767232UL, 247267328UL, 12779520UL, 13107200UL,
3799646208UL, 3431137280UL, 2878078976UL, 2291204096UL, 1586757632UL, 832176128UL, 262012928UL, 11010048UL, 11863296UL,
3763470336UL, 3394633728UL, 2891972608UL, 2288648192UL, 1651310592UL, 963706880UL, 343343104UL, 8650752UL, 10160896UL,
3912433664UL, 3442802688UL, 2956591104UL, 2403467264UL, 1766326272UL, 1078722560UL, 474939392UL, 5767168UL, 7539712UL,
4162584576UL, 3692888064UL, 3005218816UL, 2418212864UL, 1881604096UL, 1210843136UL, 590348288UL, 104071168UL, 4786688UL,
4278779904UL, 3959422976UL, 3255238656UL, 2617769984UL, 1980366848UL, 1292828672UL, 688979968UL, 219348992UL, 2293760UL,
4278190080UL, 3657433088UL, 3137339392UL, 2650800128UL, 2080374784UL, 1509949440UL, 922746880UL, 419430400UL, 0
 }; //"Thu Aug 27 02:33:34 PM"

APDK_END_NAMESPACE

==> hpijs-1.4.1.tar.gz: hpijs-1.4.1/dj895_maps.cpp <==
/*****************************************************************************\
  dj895_maps.cpp : Color maps for DJ895

  Copyright (c) 1996 - 2001, Hewlett-Packard Co.
  All rights reserved.

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:
  1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
  2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
  3. Neither the name of Hewlett-Packard nor the names of its
     contributors may be used to endorse or promote products derived
     from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR IMPLIED
  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN
  NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
  TO, PATENT INFRINGEMENT; PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
\*****************************************************************************/


#include "config.h"

#include "global_types.h"

APDK_BEGIN_NAMESPACE

uint32_t ulMapVENICE_KCMY[ 9*9*9 ]=
{
1819176703UL, 79494215UL, 112983330UL, 79035667UL, 78183948UL, 60489224UL, 59571718UL, 42007811UL, 7405312UL,
4230922555UL, 655358293UL, 176553263UL, 128253208UL, 61209869UL, 60751368UL, 26606852UL, 9305345UL, 8650496UL,
4248940299UL, 3776766759UL, 756415798UL, 308083743UL, 142671120UL, 59440646UL, 9239553UL, 9109248UL, 8779520UL,
4248086274UL, 4214276619UL, 2786390812UL, 942206231UL, 491516427UL, 224131588UL, 6616320UL, 7399168UL, 7857664UL,
4264010752UL, 4247302401UL, 4011647240UL, 2148919051UL, 993059843UL, 507241472UL, 138274048UL, 4837888UL, 5950720UL,
4262961664UL, 4246251520UL, 4229221122UL, 3239632384UL, 1763828224UL, 723902208UL, 304536064UL, 2674688UL, 3916800UL,
4278952960UL, 4245530112UL, 4245339136UL, 3641362432UL, 2265566208UL, 1108008960UL, 437574912UL, 119069440UL, 2280192UL,
4278233600UL, 4211122944UL, 4278235392UL, 3825252352UL, 2785196032UL, 1677774080UL, 738253824UL, 302835968UL, 1039616UL,
4278236928UL, 4278234112UL, 4278234368UL, 3942690560UL, 3204492544UL, 2281749504UL, 1359008000UL, 620816128UL, 65280UL,
3422292824UL, 536567352UL, 217763358UL, 133298706UL, 47578636UL, 46333448UL, 11795717UL, 11009281UL, 9365504UL,
4252790811UL, 1819700817UL, 230487086UL, 112721175UL, 61734412UL, 60882438UL, 9829634UL, 9043712UL, 7992832UL,
4233393664UL, 4064522015UL, 1346225965UL, 528017689UL, 126482957UL, 25951492UL, 8978176UL, 8648448UL, 7924992UL,
4248074240UL, 4231703558UL, 3409695758UL, 1430441485UL, 811653892UL, 308602880UL, 6545664UL, 7133696UL, 7395840UL,
4263805952UL, 4264010752UL, 4028613125UL, 2553530624UL, 1245367297UL, 524010752UL, 54051840UL, 4767488UL, 5883136UL,
4279601152UL, 4245789184UL, 4161583616UL, 2886710016UL, 1544795648UL, 689813504UL, 253801216UL, 2600448UL, 3780608UL,
4245129216UL, 4211118848UL, 3942687488UL, 3036717056UL, 2013308416UL, 1023652608UL, 369865216UL, 68201984UL, 2205952UL,
4278225408UL, 3791685632UL, 3456142080UL, 3003157760UL, 2365624576UL, 1509989376UL, 755018496UL, 167817216UL, 897024UL,
4278227456UL, 3456141056UL, 3288369152UL, 3019933952UL, 2617281536UL, 1979749120UL, 1224778496UL, 587248896UL, 48640UL,
4143384622UL, 1744640554UL, 519916828UL, 184397586UL, 50262795UL, 64486664UL, 14285826UL, 12842496UL, 10868224UL,
4255729162UL, 3084330804UL, 569604134UL, 251059983UL, 98368262UL, 13040899UL, 11861760UL, 10745856UL, 9232896UL,
4250816512UL, 4135742478UL, 2223998487UL, 1253754887UL, 228518406UL, 9499904UL, 8974336UL, 8383744UL, 7593472UL,
4248392704UL, 4249515008UL, 3461321226UL, 2172105475UL, 879538176UL, 191088128UL, 6606080UL, 7000064UL, 6868992UL,
4280572928UL, 4264064512UL, 3928660994UL, 2402325760UL, 1195023616UL, 490381056UL, 54176256UL, 4829184UL, 5683456UL,
4279723264UL, 4262689024UL, 3926823168UL, 2702347776UL, 1629131520UL, 723292928UL, 253662208UL, 2594816UL, 3842560UL,
4278676224UL, 4278220032UL, 3674242816UL, 2785051136UL, 1845527040UL, 990088448UL, 403214336UL, 34442752UL, 2069504UL,
4278219264UL, 3741346560UL, 3120591104UL, 2701161984UL, 2147514624UL, 1426095872UL, 755010048UL, 184585728UL, 692224UL,
4278220544UL, 3439356672UL, 2952818944UL, 2667607552UL, 2298509056UL, 1795193088UL, 1157661440UL, 587239936UL, 37632UL,
4259653128UL, 2868776476UL, 1174216726UL, 519914253UL, 134125065UL, 16439296UL, 15459328UL, 13752320UL, 11977728UL,
4273417220UL, 3891139612UL, 1375215645UL, 418995213UL, 49524481UL, 14866176UL, 13754624UL, 12442880UL, 10931968UL,
4269093120UL, 4221780741UL, 3066452487UL, 1153592327UL, 280338688UL, 10863360UL, 10408704UL, 9688832UL, 8900864UL,
4265753600UL, 4250487808UL, 3530710787UL, 1954444800UL, 813005824UL, 174693632UL, 6993152UL, 7062272UL, 6931456UL,
4280828416UL, 4247604224UL, 3946407424UL, 2470209280UL, 1262513408UL, 507607040UL, 54495744UL, 4955392UL, 5549056UL,
4263135488UL, 4263006720UL, 4028065024UL, 2686019584UL, 1629382400UL, 773942784UL, 253850368UL, 2851072UL, 3969280UL,
4245245184UL, 4211101952UL, 3842006784UL, 2701156864UL, 1829069568UL, 1023961088UL, 403467008UL, 814336UL, 2195200UL,
4278211840UL, 3892335360UL, 3238024960UL, 2617270528UL, 2046846208UL, 1392534784UL, 721447424UL, 184577536UL, 684544UL,
4160773120UL, 3506459648UL, 3003144704UL, 2566939392UL, 2181064448UL, 1694524928UL, 1124100608UL, 570455040UL, 29696UL,
4276100357UL, 3573419536UL, 1895633680UL, 939336200UL, 452802307UL, 16152576UL, 15248896UL, 14072320UL, 12693248UL,
4257226242UL, 4159906309UL, 2281312784UL, 905585670UL, 217727746UL, 15105792UL, 14331392UL, 13745920UL, 12433664UL,
4287243264UL, 4256376834UL, 3403102720UL, 1557018882UL, 449465600UL, 12156160UL, 12298752UL, 11779072UL, 10665472UL,
4283377152UL, 4268043520UL, 3582212864UL, 1988114432UL, 797067776UL, 142174720UL, 8163072UL, 8431872UL, 8107264UL,
4264307712UL, 4265030400UL, 3745725441UL, 2420391680UL, 1196049920UL, 491344896UL, 38169088UL, 5277952UL, 5676800UL,
4263261184UL, 4263393280UL, 3827318784UL, 2703311360UL, 1646610176UL, 807947008UL, 220681216UL, 3237376UL, 4160768UL,
4245371392UL, 4245110016UL, 3876012288UL, 2835956992UL, 1879722240UL, 1057835776UL, 420433920UL, 34690304UL, 2385920UL,
4278206208UL, 3959438848UL, 3372236800UL, 2701149696UL, 2046840064UL, 1375751936UL, 721441024UL, 184570880UL, 744448UL,
4076880896UL, 3456122880UL, 3019916032UL, 2634042112UL, 2181059840UL, 1660966656UL, 1157650176UL, 587225856UL, 23808UL,
4275835907UL, 4043119616UL, 2784892929UL, 1358829315UL, 603855360UL, 150741248UL, 15621120UL, 14257152UL, 12949760UL,
4274394113UL, 4227209216UL, 3069974272UL, 1375344384UL, 335157248UL, 15411712UL, 14508800UL, 14062848UL, 13083392UL,
4271446016UL, 4223538689UL, 3234600704UL, 1690966528UL, 550379520UL, 12791808UL, 12872192UL, 12949248UL, 12297984UL,
4284291584UL, 4268891136UL, 3448184064UL, 2038897664UL, 898441472UL, 160182784UL, 9593344UL, 10258944UL, 9870848UL,
4265024512UL, 4265484288UL, 3628671744UL, 2370708224UL, 1330915328UL, 458502656UL, 5458688UL, 6451456UL, 6785536UL,
4280427008UL, 4263715584UL, 3727172864UL, 2552701952UL, 1580018176UL, 758065920UL, 237976064UL, 3625472UL, 4484608UL,
4245628160UL, 4245563136UL, 3708758272UL, 2735614720UL, 1863331328UL, 1041445376UL, 437531904UL, 35077376UL, 2708224UL,
4278201344UL, 3992988672UL, 3355454464UL, 2717920768UL, 2063610624UL, 1308636928UL, 687879936UL, 167786752UL, 869888UL,
3774886912UL, 3288346624UL, 2919247872UL, 2566927616UL, 2181053440UL, 1660961536UL, 1140868096UL, 603997696UL, 18176UL,
4258860033UL, 4160293632UL, 3170699520UL, 1660750336UL, 738069504UL, 201198336UL, 16192256UL, 14632192UL, 13398784UL,
4257745665UL, 4226745857UL, 3220308480UL, 1609499648UL, 519046912UL, 15404032UL, 14622976UL, 14045184UL, 13400832UL,
4255321344UL, 4173399296UL, 3082880256UL, 1841497856UL, 734464512UL, 63245568UL, 12986368UL, 13195264UL, 12812800UL,
4251717120UL, 4219341568UL, 3213428736UL, 2055866880UL, 1016073472UL, 261492480UL, 10496256UL, 11098624UL, 11239936UL,
4248834304UL, 4249227520UL, 3477868032UL, 2337542144UL, 1331368192UL, 526325248UL, 6497280UL, 7885312UL, 8549376UL,
4280685824UL, 4247196672UL, 3542750208UL, 2536379136UL, 1614091776UL, 808916992UL, 205005312UL, 4472320UL, 5463552UL,
4279637504UL, 4229240832UL, 3490911488UL, 2635339520UL, 1779897856UL, 974723328UL, 505355520UL, 1910528UL, 3097600UL,
4194310144UL, 4060092672UL, 3405781504UL, 2684361472UL, 1962941440UL, 1241652992UL, 654582016UL, 184951552UL, 1192960UL,
3590333184UL, 3154125056UL, 2818580992UL, 2466259712UL, 2080384512UL, 1593846528UL, 1073753856UL, 570437632UL, 12800UL,
4208197632UL, 4227006464UL, 3506110464UL, 2113470464UL, 955777024UL, 402457344UL, 33358080UL, 15994112UL, 14235904UL,
4291166208UL, 3956736000UL, 3151429632UL, 2044329984UL, 903675904UL, 249626624UL, 14485504UL, 14096128UL, 13712896UL,
4289003520UL, 3836936192UL, 2947678208UL, 2109079552UL, 1035796480UL, 281018368UL, 12716544UL, 13114880UL, 13190656UL,
4201906176UL, 3900702720UL, 2978611200UL, 2139881472UL, 1217462272UL, 412418048UL, 10356992UL, 11543296UL, 12013056UL,
4249355008UL, 4081647616UL, 3209887744UL, 2254045184UL, 1365114880UL, 610533888UL, 74187776UL, 8725504UL, 9588224UL,
4247389696UL, 4180346112UL, 3425633280UL, 2486436864UL, 1631192064UL, 842925568UL, 222365696UL, 5447936UL, 6702592UL,
4279634432UL, 4145482496UL, 3373664256UL, 2585331456UL, 1797064704UL, 1025509632UL, 472124416UL, 2561536UL, 3945984UL,
4278651648UL, 4077259776UL, 3355707904UL, 2667908096UL, 1963395840UL, 1225263872UL, 638193152UL, 370546176UL, 1713152UL,
3858764288UL, 3321893376UL, 2868908800UL, 2432701184UL, 2013271552UL, 1526732288UL, 1006639104UL, 520100096UL, 7168UL,
4293197824UL, 4293918720UL, 3673292800UL, 2616262656UL, 1492058112UL, 770834432UL, 334888960UL, 100335616UL, 16711680UL,
4223860736UL, 3602972672UL, 3066298368UL, 2395668480UL, 1422917632UL, 684982272UL, 249036800UL, 14352384UL, 14417920UL,
4020436992UL, 3517448192UL, 2896822272UL, 2309947392UL, 1488191488UL, 716767232UL, 247267328UL, 12779520UL, 13107200UL,
3799646208UL, 3431137280UL, 2878078976UL, 2291204096UL, 1586757632UL, 832176128UL, 262012928UL, 11010048UL, 11863296UL,
3763470336UL, 3394633728UL, 2891972608UL, 2288648192UL, 1651310592UL, 963706880UL, 343343104UL, 8650752UL, 10160896UL,
3912433664UL, 3442802688UL, 2956591104UL, 2403467264UL, 1766326272UL, 1078722560UL, 474939392UL, 5767168UL, 7539712UL,
4162584576UL, 3692888064UL, 3005218816UL, 2418212864UL, 1881604096UL, 1210843136UL, 590348288UL, 104071168UL, 4786688UL,
4278779904UL, 3959422976UL, 3255238656UL, 2617769984UL, 1980366848UL, 1292828672UL, 688979968UL, 219348992UL, 2293760UL,
4278190080UL, 3657433088UL, 3137339392UL, 2650800128UL, 2080374784UL, 1509949440UL, 922746880UL, 419430400UL, 0
 }; //"Thu Aug 27 02:33:34 PM"

APDK_END_NAMESPACE
